function [residual, g1, g2, g3] = bmcomp2_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           columns: equations in order of declaration
%                                                           rows: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              columns: equations in order of declaration
%                                                              rows: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              columns: equations in order of declaration
%                                                              rows: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(25, 1);
T15 = params(4)/2;
T17 = exp(y(11));
T43 = exp(y(8))*(1-params(5))*(1+params(11)-params(5)/(params(5)-1)*exp(y(5)));
T64 = exp(y(5)+y(13)-y(9));
T118 = T64*y(21);
T122 = (-(exp(y(8))*(1-params(5))*(-(params(5)/(params(5)-1)*exp(y(5))))));
T123 = y(20)*T122;
T124 = T118+T123;
T144 = (-(params(6)*(params(6)-1)*exp(y(12)+y(6)*(params(6)-1))));
T150 = y(25)*T144+y(19)*(-(params(6)*exp(y(12)+params(6)*y(6))));
T169 = (-(exp(y(31))*(exp(y(31))-1)*params(4)*params(1)*params(2)*exp((-params(2))*(y(30)-y(7)))));
T176 = params(12)^(-1);
T209 = y(21)*(-T64);
T218 = y(28)*(-exp(y(9)-y(14)))+exp(y(13)-y(9))*y(27)+exp(y(9))*y(23)+T209+params(12)*y(32)*(-(exp(y(9))*params(7)));
T229 = T17*params(4)*(T17-1)+T17*params(4)*T17;
T234 = (-(T15*T17*2*(T17-1)));
T243 = T17*(T17-1)*params(4)*params(1)*exp((-params(2))*(y(7)-y(1)))+T17*T17*params(4)*params(1)*exp((-params(2))*(y(7)-y(1)));
T319 = y(25)*(-(params(6)*(params(6)-1)*(params(6)-1)*exp(y(12)+y(6)*(params(6)-1))))+y(19)*(-(params(6)*params(6)*exp(y(12)+params(6)*y(6))));
T342 = T17*(T17-1)*params(4)*params(1)*params(2)*exp((-params(2))*(y(7)-y(1)))+T17*T17*params(4)*params(1)*params(2)*exp((-params(2))*(y(7)-y(1)));
T361 = (-(exp(y(31))*(exp(y(31))-1)*params(4)*params(1)*params(2)*params(2)*exp((-params(2))*(y(30)-y(7)))));
T377 = T17*(T17-1)*params(4)*params(1)*(-params(2))*exp((-params(2))*(y(7)-y(1)))+T17*T17*params(4)*params(1)*(-params(2))*exp((-params(2))*(y(7)-y(1)));
T380 = T176*y(4)*(-T377);
T411 = T17*T17*params(4)*params(1)*exp((-params(2))*(y(7)-y(1)))+T17*T17*params(4)*params(1)*exp((-params(2))*(y(7)-y(1)));
T419 = exp(y(31))*(exp(y(31))-1)*params(4)*params(1)*params(2)*exp((-params(2))*(y(30)-y(7)))+exp(y(31))*exp(y(31))*params(4)*params(1)*params(2)*exp((-params(2))*(y(30)-y(7)));
T424 = exp(y(31))*params(4)*params(1)*exp((-params(2))*(y(30)-y(7)))*(exp(y(31))-1)+exp(y(31))*params(4)*params(1)*exp((-params(2))*(y(30)-y(7)))*exp(y(31));
T530 = T176*y(4)*(-(T17*(T17-1)*params(4)*params(1)*(-params(2))*params(2)*exp((-params(2))*(y(7)-y(1)))+T17*T17*params(4)*params(1)*(-params(2))*params(2)*exp((-params(2))*(y(7)-y(1)))));
T536 = T176*y(4)*(-(T17*(T17-1)*params(4)*params(1)*(-params(2))*(-params(2))*exp((-params(2))*(y(7)-y(1)))+T17*T17*params(4)*params(1)*(-params(2))*(-params(2))*exp((-params(2))*(y(7)-y(1)))));
T541 = T176*y(4)*(-(T377+T17*T17*params(4)*params(1)*(-params(2))*exp((-params(2))*(y(7)-y(1)))+T17*T17*params(4)*params(1)*(-params(2))*exp((-params(2))*(y(7)-y(1)))));
residual(1) = T124;
residual(2) = (-(params(8)*(1+params(3))*exp(y(6)*(1+params(3)))/(1+params(3))))+y(29)*(-exp(y(6)))+y(26)*(-(params(8)*params(3)*exp(y(6)*params(3)+y(7)*params(2))))+T150;
residual(3) = (1-params(2))*exp(y(7)*(1-params(2)))/(1-params(2))+y(26)*(-(params(8)*params(2)*exp(y(6)*params(3)+y(7)*params(2))))+y(20)*T169+y(18)*(-exp(y(7)))+T176*y(4)*(-(T17*(T17-1)*params(4)*params(1)*(-params(2))*exp((-params(2))*(y(7)-y(1)))));
residual(4) = y(20)*(-T43)+exp(y(8))*y(19)+exp(y(8))*y(18);
residual(5) = T218;
residual(6) = y(23)*(-((1-params(7))*exp(y(10))))+y(22)*(-exp(y(14)-y(10)));
residual(7) = y(20)*T229+y(18)*T234+T176*y(4)*(-T243);
residual(8) = y(25)*(-(params(6)*exp(y(12)+y(6)*(params(6)-1))))+y(24)+y(19)*(-exp(y(12)+params(6)*y(6)))+params(12)*y(33)*(-params(9));
residual(9) = y(27)*(-exp(y(13)-y(9)))+T118+exp(y(13))*y(25);
residual(10) = exp(y(9)-y(14))*y(28)+exp(y(14))*y(26)+exp(y(14)-y(10))*y(22);
residual(11) = exp(y(15))*y(27);
residual(12) = exp(y(16))*y(28);
residual(13) = exp(y(17))*y(29);
residual(14) = exp(y(8))-(exp(y(7))+params(10)+T15*(T17-1)^2);
residual(15) = exp(y(8))-exp(y(12)+params(6)*y(6));
residual(16) = T17*params(4)*(T17-1)-(T43+exp(y(31))*params(4)*params(1)*exp((-params(2))*(y(30)-y(7)))*(exp(y(31))-1));
residual(17) = T64-1;
residual(18) = exp(y(14)-y(10))-1;
residual(19) = exp(y(9))-(params(7)*exp(y(2))+(1-params(7))*exp(y(10)));
residual(20) = y(12)-(params(9)*y(3)+x(it_, 1));
residual(21) = exp(y(13))-params(6)*exp(y(12)+y(6)*(params(6)-1));
residual(22) = exp(y(14))-params(8)*exp(y(6)*params(3)+y(7)*params(2));
residual(23) = exp(y(15))-exp(y(13)-y(9));
residual(24) = exp(y(16))-exp(y(9)-y(14));
residual(25) = exp(y(17))-exp(y(6));
if nargout >= 2,
  g1 = zeros(25, 34);

  %
  % Jacobian matrix
  %

  g1(1,5)=T124;
  g1(1,8)=T123;
  g1(1,9)=T209;
  g1(1,13)=T118;
  g1(1,20)=T122;
  g1(1,21)=T64;
  g1(2,6)=(-(params(8)*(1+params(3))*(1+params(3))*exp(y(6)*(1+params(3)))/(1+params(3))))+y(29)*(-exp(y(6)))+y(26)*(-(params(8)*params(3)*params(3)*exp(y(6)*params(3)+y(7)*params(2))))+T319;
  g1(2,7)=y(26)*(-(params(8)*params(3)*params(2)*exp(y(6)*params(3)+y(7)*params(2))));
  g1(2,12)=T150;
  g1(2,19)=(-(params(6)*exp(y(12)+params(6)*y(6))));
  g1(2,25)=T144;
  g1(2,26)=(-(params(8)*params(3)*exp(y(6)*params(3)+y(7)*params(2))));
  g1(2,29)=(-exp(y(6)));
  g1(3,6)=y(26)*(-(params(8)*params(2)*params(3)*exp(y(6)*params(3)+y(7)*params(2))));
  g1(3,1)=T176*y(4)*(-(T17*(T17-1)*params(4)*params(1)*(-params(2))*params(2)*exp((-params(2))*(y(7)-y(1)))));
  g1(3,7)=(1-params(2))*(1-params(2))*exp(y(7)*(1-params(2)))/(1-params(2))+y(26)*(-(params(8)*params(2)*params(2)*exp(y(6)*params(3)+y(7)*params(2))))+y(18)*(-exp(y(7)))+y(20)*T361+T176*y(4)*(-(T17*(T17-1)*params(4)*params(1)*(-params(2))*(-params(2))*exp((-params(2))*(y(7)-y(1)))));
  g1(3,30)=y(20)*(-(exp(y(31))*(exp(y(31))-1)*params(4)*params(1)*params(2)*(-params(2))*exp((-params(2))*(y(30)-y(7)))));
  g1(3,11)=T380;
  g1(3,31)=y(20)*(-T419);
  g1(3,18)=(-exp(y(7)));
  g1(3,4)=T176*(-(T17*(T17-1)*params(4)*params(1)*(-params(2))*exp((-params(2))*(y(7)-y(1)))));
  g1(3,20)=T169;
  g1(3,26)=(-(params(8)*params(2)*exp(y(6)*params(3)+y(7)*params(2))));
  g1(4,5)=T123;
  g1(4,8)=y(20)*(-T43)+exp(y(8))*y(19)+exp(y(8))*y(18);
  g1(4,18)=exp(y(8));
  g1(4,19)=exp(y(8));
  g1(4,20)=(-T43);
  g1(5,5)=T209;
  g1(5,9)=y(28)*(-exp(y(9)-y(14)))+y(27)*(-exp(y(13)-y(9)))+exp(y(9))*y(23)+T118+params(12)*y(32)*(-(exp(y(9))*params(7)));
  g1(5,13)=exp(y(13)-y(9))*y(27)+T209;
  g1(5,14)=exp(y(9)-y(14))*y(28);
  g1(5,21)=(-T64);
  g1(5,23)=exp(y(9));
  g1(5,32)=params(12)*(-(exp(y(9))*params(7)));
  g1(5,27)=exp(y(13)-y(9));
  g1(5,28)=(-exp(y(9)-y(14)));
  g1(6,10)=y(23)*(-((1-params(7))*exp(y(10))))+exp(y(14)-y(10))*y(22);
  g1(6,14)=y(22)*(-exp(y(14)-y(10)));
  g1(6,22)=(-exp(y(14)-y(10)));
  g1(6,23)=(-((1-params(7))*exp(y(10))));
  g1(7,1)=T176*y(4)*(-T342);
  g1(7,7)=T380;
  g1(7,11)=y(20)*(T229+T17*params(4)*T17+T17*params(4)*T17)+y(18)*(-(T15*(T17*2*(T17-1)+T17*2*T17)))+T176*y(4)*(-(T243+T411));
  g1(7,18)=T234;
  g1(7,4)=T176*(-T243);
  g1(7,20)=T229;
  g1(8,6)=T150;
  g1(8,12)=y(25)*(-(params(6)*exp(y(12)+y(6)*(params(6)-1))))+y(19)*(-exp(y(12)+params(6)*y(6)));
  g1(8,19)=(-exp(y(12)+params(6)*y(6)));
  g1(8,24)=1;
  g1(8,33)=params(12)*(-params(9));
  g1(8,25)=(-(params(6)*exp(y(12)+y(6)*(params(6)-1))));
  g1(9,5)=T118;
  g1(9,9)=exp(y(13)-y(9))*y(27)+T209;
  g1(9,13)=y(27)*(-exp(y(13)-y(9)))+T118+exp(y(13))*y(25);
  g1(9,21)=T64;
  g1(9,25)=exp(y(13));
  g1(9,27)=(-exp(y(13)-y(9)));
  g1(10,9)=exp(y(9)-y(14))*y(28);
  g1(10,10)=y(22)*(-exp(y(14)-y(10)));
  g1(10,14)=y(28)*(-exp(y(9)-y(14)))+exp(y(14))*y(26)+exp(y(14)-y(10))*y(22);
  g1(10,22)=exp(y(14)-y(10));
  g1(10,26)=exp(y(14));
  g1(10,28)=exp(y(9)-y(14));
  g1(11,15)=exp(y(15))*y(27);
  g1(11,27)=exp(y(15));
  g1(12,16)=exp(y(16))*y(28);
  g1(12,28)=exp(y(16));
  g1(13,17)=exp(y(17))*y(29);
  g1(13,29)=exp(y(17));
  g1(14,7)=(-exp(y(7)));
  g1(14,8)=exp(y(8));
  g1(14,11)=T234;
  g1(15,6)=(-(params(6)*exp(y(12)+params(6)*y(6))));
  g1(15,8)=exp(y(8));
  g1(15,12)=(-exp(y(12)+params(6)*y(6)));
  g1(16,5)=T122;
  g1(16,7)=T169;
  g1(16,30)=(-(exp(y(31))*(exp(y(31))-1)*params(4)*params(1)*(-params(2))*exp((-params(2))*(y(30)-y(7)))));
  g1(16,8)=(-T43);
  g1(16,11)=T229;
  g1(16,31)=(-T424);
  g1(17,5)=T64;
  g1(17,9)=(-T64);
  g1(17,13)=T64;
  g1(18,10)=(-exp(y(14)-y(10)));
  g1(18,14)=exp(y(14)-y(10));
  g1(19,2)=(-(params(7)*exp(y(2))));
  g1(19,9)=exp(y(9));
  g1(19,10)=(-((1-params(7))*exp(y(10))));
  g1(20,3)=(-params(9));
  g1(20,12)=1;
  g1(20,34)=(-1);
  g1(21,6)=T144;
  g1(21,12)=(-(params(6)*exp(y(12)+y(6)*(params(6)-1))));
  g1(21,13)=exp(y(13));
  g1(22,6)=(-(params(8)*params(3)*exp(y(6)*params(3)+y(7)*params(2))));
  g1(22,7)=(-(params(8)*params(2)*exp(y(6)*params(3)+y(7)*params(2))));
  g1(22,14)=exp(y(14));
  g1(23,9)=exp(y(13)-y(9));
  g1(23,13)=(-exp(y(13)-y(9)));
  g1(23,15)=exp(y(15));
  g1(24,9)=(-exp(y(9)-y(14)));
  g1(24,14)=exp(y(9)-y(14));
  g1(24,16)=exp(y(16));
  g1(25,6)=(-exp(y(6)));
  g1(25,17)=exp(y(17));
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  v2 = zeros(271,3);
  v2(1,1)=1;
  v2(1,2)=141;
  v2(1,3)=T124;
  v2(2,1)=1;
  v2(2,2)=243;
  v2(2,3)=T123;
  v2(3,1)=1;
  v2(3,2)=144;
  v2(3,3)=  v2(2,3);
  v2(4,1)=1;
  v2(4,2)=246;
  v2(4,3)=T123;
  v2(5,1)=1;
  v2(5,2)=277;
  v2(5,3)=T209;
  v2(6,1)=1;
  v2(6,2)=145;
  v2(6,3)=  v2(5,3);
  v2(7,1)=1;
  v2(7,2)=281;
  v2(7,3)=T118;
  v2(8,1)=1;
  v2(8,2)=413;
  v2(8,3)=T118;
  v2(9,1)=1;
  v2(9,2)=149;
  v2(9,3)=  v2(8,3);
  v2(10,1)=1;
  v2(10,2)=417;
  v2(10,3)=T209;
  v2(11,1)=1;
  v2(11,2)=285;
  v2(11,3)=  v2(10,3);
  v2(12,1)=1;
  v2(12,2)=421;
  v2(12,3)=T118;
  v2(13,1)=1;
  v2(13,2)=651;
  v2(13,3)=T122;
  v2(14,1)=1;
  v2(14,2)=156;
  v2(14,3)=  v2(13,3);
  v2(15,1)=1;
  v2(15,2)=654;
  v2(15,3)=T122;
  v2(16,1)=1;
  v2(16,2)=258;
  v2(16,3)=  v2(15,3);
  v2(17,1)=1;
  v2(17,2)=685;
  v2(17,3)=T64;
  v2(18,1)=1;
  v2(18,2)=157;
  v2(18,3)=  v2(17,3);
  v2(19,1)=1;
  v2(19,2)=689;
  v2(19,3)=(-T64);
  v2(20,1)=1;
  v2(20,2)=293;
  v2(20,3)=  v2(19,3);
  v2(21,1)=1;
  v2(21,2)=693;
  v2(21,3)=T64;
  v2(22,1)=1;
  v2(22,2)=429;
  v2(22,3)=  v2(21,3);
  v2(23,1)=2;
  v2(23,2)=176;
  v2(23,3)=(-(params(8)*(1+params(3))*(1+params(3))*(1+params(3))*exp(y(6)*(1+params(3)))/(1+params(3))))+y(29)*(-exp(y(6)))+y(26)*(-(params(8)*params(3)*params(3)*params(3)*exp(y(6)*params(3)+y(7)*params(2))))+y(25)*(-(params(6)*(params(6)-1)*(params(6)-1)*(params(6)-1)*exp(y(12)+y(6)*(params(6)-1))))+y(19)*(-(params(6)*params(6)*params(6)*exp(y(12)+params(6)*y(6))));
  v2(24,1)=2;
  v2(24,2)=210;
  v2(24,3)=y(26)*(-(params(8)*params(3)*params(2)*params(3)*exp(y(6)*params(3)+y(7)*params(2))));
  v2(25,1)=2;
  v2(25,2)=177;
  v2(25,3)=  v2(24,3);
  v2(26,1)=2;
  v2(26,2)=211;
  v2(26,3)=y(26)*(-(params(8)*params(3)*params(2)*params(2)*exp(y(6)*params(3)+y(7)*params(2))));
  v2(27,1)=2;
  v2(27,2)=380;
  v2(27,3)=T319;
  v2(28,1)=2;
  v2(28,2)=182;
  v2(28,3)=  v2(27,3);
  v2(29,1)=2;
  v2(29,2)=386;
  v2(29,3)=T150;
  v2(30,1)=2;
  v2(30,2)=618;
  v2(30,3)=(-(params(6)*params(6)*exp(y(12)+params(6)*y(6))));
  v2(31,1)=2;
  v2(31,2)=189;
  v2(31,3)=  v2(30,3);
  v2(32,1)=2;
  v2(32,2)=624;
  v2(32,3)=(-(params(6)*exp(y(12)+params(6)*y(6))));
  v2(33,1)=2;
  v2(33,2)=393;
  v2(33,3)=  v2(32,3);
  v2(34,1)=2;
  v2(34,2)=822;
  v2(34,3)=(-(params(6)*(params(6)-1)*(params(6)-1)*exp(y(12)+y(6)*(params(6)-1))));
  v2(35,1)=2;
  v2(35,2)=195;
  v2(35,3)=  v2(34,3);
  v2(36,1)=2;
  v2(36,2)=828;
  v2(36,3)=T144;
  v2(37,1)=2;
  v2(37,2)=399;
  v2(37,3)=  v2(36,3);
  v2(38,1)=2;
  v2(38,2)=856;
  v2(38,3)=(-(params(8)*params(3)*params(3)*exp(y(6)*params(3)+y(7)*params(2))));
  v2(39,1)=2;
  v2(39,2)=196;
  v2(39,3)=  v2(38,3);
  v2(40,1)=2;
  v2(40,2)=857;
  v2(40,3)=(-(params(8)*params(3)*params(2)*exp(y(6)*params(3)+y(7)*params(2))));
  v2(41,1)=2;
  v2(41,2)=230;
  v2(41,3)=  v2(40,3);
  v2(42,1)=2;
  v2(42,2)=958;
  v2(42,3)=(-exp(y(6)));
  v2(43,1)=2;
  v2(43,2)=199;
  v2(43,3)=  v2(42,3);
  v2(44,1)=3;
  v2(44,2)=176;
  v2(44,3)=y(26)*(-(params(8)*params(2)*params(3)*params(3)*exp(y(6)*params(3)+y(7)*params(2))));
  v2(45,1)=3;
  v2(45,2)=1;
  v2(45,3)=T176*y(4)*(-(T17*(T17-1)*params(4)*params(1)*(-params(2))*params(2)*params(2)*exp((-params(2))*(y(7)-y(1)))));
  v2(46,1)=3;
  v2(46,2)=210;
  v2(46,3)=y(26)*(-(params(8)*params(2)*params(2)*params(3)*exp(y(6)*params(3)+y(7)*params(2))));
  v2(47,1)=3;
  v2(47,2)=177;
  v2(47,3)=  v2(46,3);
  v2(48,1)=3;
  v2(48,2)=205;
  v2(48,3)=T176*y(4)*(-(T17*(T17-1)*params(4)*params(1)*(-params(2))*(-params(2))*params(2)*exp((-params(2))*(y(7)-y(1)))));
  v2(49,1)=3;
  v2(49,2)=7;
  v2(49,3)=  v2(48,3);
  v2(50,1)=3;
  v2(50,2)=211;
  v2(50,3)=(1-params(2))*(1-params(2))*(1-params(2))*exp(y(7)*(1-params(2)))/(1-params(2))+y(26)*(-(params(8)*params(2)*params(2)*params(2)*exp(y(6)*params(3)+y(7)*params(2))))+y(18)*(-exp(y(7)))+y(20)*(-(exp(y(31))*(exp(y(31))-1)*params(4)*params(1)*params(2)*params(2)*params(2)*exp((-params(2))*(y(30)-y(7)))))+T176*y(4)*(-(T17*(T17-1)*params(4)*params(1)*(-params(2))*(-params(2))*(-params(2))*exp((-params(2))*(y(7)-y(1)))));
  v2(51,1)=3;
  v2(51,2)=993;
  v2(51,3)=y(20)*(-(exp(y(31))*(exp(y(31))-1)*params(4)*params(1)*params(2)*(-params(2))*params(2)*exp((-params(2))*(y(30)-y(7)))));
  v2(52,1)=3;
  v2(52,2)=234;
  v2(52,3)=  v2(51,3);
  v2(53,1)=3;
  v2(53,2)=1016;
  v2(53,3)=y(20)*(-(exp(y(31))*(exp(y(31))-1)*params(4)*params(1)*params(2)*(-params(2))*(-params(2))*exp((-params(2))*(y(30)-y(7)))));
  v2(54,1)=3;
  v2(54,2)=341;
  v2(54,3)=T530;
  v2(55,1)=3;
  v2(55,2)=11;
  v2(55,3)=  v2(54,3);
  v2(56,1)=3;
  v2(56,2)=347;
  v2(56,3)=T536;
  v2(57,1)=3;
  v2(57,2)=215;
  v2(57,3)=  v2(56,3);
  v2(58,1)=3;
  v2(58,2)=351;
  v2(58,3)=T541;
  v2(59,1)=3;
  v2(59,2)=1027;
  v2(59,3)=y(20)*(-(exp(y(31))*(exp(y(31))-1)*params(4)*params(1)*params(2)*params(2)*exp((-params(2))*(y(30)-y(7)))+exp(y(31))*exp(y(31))*params(4)*params(1)*params(2)*params(2)*exp((-params(2))*(y(30)-y(7)))));
  v2(60,1)=3;
  v2(60,2)=235;
  v2(60,3)=  v2(59,3);
  v2(61,1)=3;
  v2(61,2)=1050;
  v2(61,3)=y(20)*(-(exp(y(31))*(exp(y(31))-1)*params(4)*params(1)*params(2)*(-params(2))*exp((-params(2))*(y(30)-y(7)))+exp(y(31))*exp(y(31))*params(4)*params(1)*params(2)*(-params(2))*exp((-params(2))*(y(30)-y(7)))));
  v2(62,1)=3;
  v2(62,2)=1017;
  v2(62,3)=  v2(61,3);
  v2(63,1)=3;
  v2(63,2)=1051;
  v2(63,3)=y(20)*(-(T419+exp(y(31))*exp(y(31))*params(4)*params(1)*params(2)*exp((-params(2))*(y(30)-y(7)))+exp(y(31))*exp(y(31))*params(4)*params(1)*params(2)*exp((-params(2))*(y(30)-y(7)))));
  v2(64,1)=3;
  v2(64,2)=585;
  v2(64,3)=(-exp(y(7)));
  v2(65,1)=3;
  v2(65,2)=222;
  v2(65,3)=  v2(64,3);
  v2(66,1)=3;
  v2(66,2)=103;
  v2(66,3)=T176*(-(T17*(T17-1)*params(4)*params(1)*(-params(2))*params(2)*exp((-params(2))*(y(7)-y(1)))));
  v2(67,1)=3;
  v2(67,2)=4;
  v2(67,3)=  v2(66,3);
  v2(68,1)=3;
  v2(68,2)=109;
  v2(68,3)=T176*(-(T17*(T17-1)*params(4)*params(1)*(-params(2))*(-params(2))*exp((-params(2))*(y(7)-y(1)))));
  v2(69,1)=3;
  v2(69,2)=208;
  v2(69,3)=  v2(68,3);
  v2(70,1)=3;
  v2(70,2)=113;
  v2(70,3)=T176*(-T377);
  v2(71,1)=3;
  v2(71,2)=344;
  v2(71,3)=  v2(70,3);
  v2(72,1)=3;
  v2(72,2)=653;
  v2(72,3)=T361;
  v2(73,1)=3;
  v2(73,2)=224;
  v2(73,3)=  v2(72,3);
  v2(74,1)=3;
  v2(74,2)=676;
  v2(74,3)=(-(exp(y(31))*(exp(y(31))-1)*params(4)*params(1)*params(2)*(-params(2))*exp((-params(2))*(y(30)-y(7)))));
  v2(75,1)=3;
  v2(75,2)=1006;
  v2(75,3)=  v2(74,3);
  v2(76,1)=3;
  v2(76,2)=677;
  v2(76,3)=(-T419);
  v2(77,1)=3;
  v2(77,2)=1040;
  v2(77,3)=  v2(76,3);
  v2(78,1)=3;
  v2(78,2)=856;
  v2(78,3)=(-(params(8)*params(2)*params(3)*exp(y(6)*params(3)+y(7)*params(2))));
  v2(79,1)=3;
  v2(79,2)=196;
  v2(79,3)=  v2(78,3);
  v2(80,1)=3;
  v2(80,2)=857;
  v2(80,3)=(-(params(8)*params(2)*params(2)*exp(y(6)*params(3)+y(7)*params(2))));
  v2(81,1)=3;
  v2(81,2)=230;
  v2(81,3)=  v2(80,3);
  v2(82,1)=4;
  v2(82,2)=141;
  v2(82,3)=T123;
  v2(83,1)=4;
  v2(83,2)=243;
  v2(83,3)=T123;
  v2(84,1)=4;
  v2(84,2)=144;
  v2(84,3)=  v2(83,3);
  v2(85,1)=4;
  v2(85,2)=246;
  v2(85,3)=y(20)*(-T43)+exp(y(8))*y(19)+exp(y(8))*y(18);
  v2(86,1)=4;
  v2(86,2)=586;
  v2(86,3)=exp(y(8));
  v2(87,1)=4;
  v2(87,2)=256;
  v2(87,3)=  v2(86,3);
  v2(88,1)=4;
  v2(88,2)=620;
  v2(88,3)=exp(y(8));
  v2(89,1)=4;
  v2(89,2)=257;
  v2(89,3)=  v2(88,3);
  v2(90,1)=4;
  v2(90,2)=651;
  v2(90,3)=T122;
  v2(91,1)=4;
  v2(91,2)=156;
  v2(91,3)=  v2(90,3);
  v2(92,1)=4;
  v2(92,2)=654;
  v2(92,3)=(-T43);
  v2(93,1)=4;
  v2(93,2)=258;
  v2(93,3)=  v2(92,3);
  v2(94,1)=5;
  v2(94,2)=141;
  v2(94,3)=T209;
  v2(95,1)=5;
  v2(95,2)=277;
  v2(95,3)=T118;
  v2(96,1)=5;
  v2(96,2)=145;
  v2(96,3)=  v2(95,3);
  v2(97,1)=5;
  v2(97,2)=281;
  v2(97,3)=T218;
  v2(98,1)=5;
  v2(98,2)=413;
  v2(98,3)=T209;
  v2(99,1)=5;
  v2(99,2)=149;
  v2(99,3)=  v2(98,3);
  v2(100,1)=5;
  v2(100,2)=417;
  v2(100,3)=T118+y(27)*(-exp(y(13)-y(9)));
  v2(101,1)=5;
  v2(101,2)=285;
  v2(101,3)=  v2(100,3);
  v2(102,1)=5;
  v2(102,2)=421;
  v2(102,3)=exp(y(13)-y(9))*y(27)+T209;
  v2(103,1)=5;
  v2(103,2)=451;
  v2(103,3)=exp(y(9)-y(14))*y(28);
  v2(104,1)=5;
  v2(104,2)=286;
  v2(104,3)=  v2(103,3);
  v2(105,1)=5;
  v2(105,2)=456;
  v2(105,3)=y(28)*(-exp(y(9)-y(14)));
  v2(106,1)=5;
  v2(106,2)=685;
  v2(106,3)=(-T64);
  v2(107,1)=5;
  v2(107,2)=157;
  v2(107,3)=  v2(106,3);
  v2(108,1)=5;
  v2(108,2)=689;
  v2(108,3)=T64;
  v2(109,1)=5;
  v2(109,2)=293;
  v2(109,3)=  v2(108,3);
  v2(110,1)=5;
  v2(110,2)=693;
  v2(110,3)=(-T64);
  v2(111,1)=5;
  v2(111,2)=429;
  v2(111,3)=  v2(110,3);
  v2(112,1)=5;
  v2(112,2)=757;
  v2(112,3)=exp(y(9));
  v2(113,1)=5;
  v2(113,2)=295;
  v2(113,3)=  v2(112,3);
  v2(114,1)=5;
  v2(114,2)=1063;
  v2(114,3)=params(12)*(-(exp(y(9))*params(7)));
  v2(115,1)=5;
  v2(115,2)=304;
  v2(115,3)=  v2(114,3);
  v2(116,1)=5;
  v2(116,2)=893;
  v2(116,3)=(-exp(y(13)-y(9)));
  v2(117,1)=5;
  v2(117,2)=299;
  v2(117,3)=  v2(116,3);
  v2(118,1)=5;
  v2(118,2)=897;
  v2(118,3)=exp(y(13)-y(9));
  v2(119,1)=5;
  v2(119,2)=435;
  v2(119,3)=  v2(118,3);
  v2(120,1)=5;
  v2(120,2)=927;
  v2(120,3)=(-exp(y(9)-y(14)));
  v2(121,1)=5;
  v2(121,2)=300;
  v2(121,3)=  v2(120,3);
  v2(122,1)=5;
  v2(122,2)=932;
  v2(122,3)=exp(y(9)-y(14));
  v2(123,1)=5;
  v2(123,2)=470;
  v2(123,3)=  v2(122,3);
  v2(124,1)=6;
  v2(124,2)=316;
  v2(124,3)=y(23)*(-((1-params(7))*exp(y(10))))+y(22)*(-exp(y(14)-y(10)));
  v2(125,1)=6;
  v2(125,2)=452;
  v2(125,3)=exp(y(14)-y(10))*y(22);
  v2(126,1)=6;
  v2(126,2)=320;
  v2(126,3)=  v2(125,3);
  v2(127,1)=6;
  v2(127,2)=456;
  v2(127,3)=y(22)*(-exp(y(14)-y(10)));
  v2(128,1)=6;
  v2(128,2)=724;
  v2(128,3)=exp(y(14)-y(10));
  v2(129,1)=6;
  v2(129,2)=328;
  v2(129,3)=  v2(128,3);
  v2(130,1)=6;
  v2(130,2)=728;
  v2(130,3)=(-exp(y(14)-y(10)));
  v2(131,1)=6;
  v2(131,2)=464;
  v2(131,3)=  v2(130,3);
  v2(132,1)=6;
  v2(132,2)=758;
  v2(132,3)=(-((1-params(7))*exp(y(10))));
  v2(133,1)=6;
  v2(133,2)=329;
  v2(133,3)=  v2(132,3);
  v2(134,1)=7;
  v2(134,2)=1;
  v2(134,3)=T176*y(4)*(-(T17*(T17-1)*params(4)*params(1)*params(2)*params(2)*exp((-params(2))*(y(7)-y(1)))+T17*T17*params(4)*params(1)*params(2)*params(2)*exp((-params(2))*(y(7)-y(1)))));
  v2(135,1)=7;
  v2(135,2)=205;
  v2(135,3)=T530;
  v2(136,1)=7;
  v2(136,2)=7;
  v2(136,3)=  v2(135,3);
  v2(137,1)=7;
  v2(137,2)=211;
  v2(137,3)=T536;
  v2(138,1)=7;
  v2(138,2)=341;
  v2(138,3)=T176*y(4)*(-(T342+T17*T17*params(4)*params(1)*params(2)*exp((-params(2))*(y(7)-y(1)))+T17*T17*params(4)*params(1)*params(2)*exp((-params(2))*(y(7)-y(1)))));
  v2(139,1)=7;
  v2(139,2)=11;
  v2(139,3)=  v2(138,3);
  v2(140,1)=7;
  v2(140,2)=347;
  v2(140,3)=T541;
  v2(141,1)=7;
  v2(141,2)=215;
  v2(141,3)=  v2(140,3);
  v2(142,1)=7;
  v2(142,2)=351;
  v2(142,3)=y(20)*(T229+T17*params(4)*T17+T17*params(4)*T17+T17*params(4)*T17+T17*params(4)*T17+T17*params(4)*T17+T17*params(4)*T17)+y(18)*(-(T15*(T17*2*(T17-1)+T17*2*T17+T17*2*T17+T17*2*T17)))+T176*y(4)*(-(T243+T411+T411+T411));
  v2(143,1)=7;
  v2(143,2)=589;
  v2(143,3)=(-(T15*(T17*2*(T17-1)+T17*2*T17)));
  v2(144,1)=7;
  v2(144,2)=358;
  v2(144,3)=  v2(143,3);
  v2(145,1)=7;
  v2(145,2)=103;
  v2(145,3)=T176*(-T342);
  v2(146,1)=7;
  v2(146,2)=4;
  v2(146,3)=  v2(145,3);
  v2(147,1)=7;
  v2(147,2)=109;
  v2(147,3)=T176*(-T377);
  v2(148,1)=7;
  v2(148,2)=208;
  v2(148,3)=  v2(147,3);
  v2(149,1)=7;
  v2(149,2)=113;
  v2(149,3)=T176*(-(T243+T411));
  v2(150,1)=7;
  v2(150,2)=344;
  v2(150,3)=  v2(149,3);
  v2(151,1)=7;
  v2(151,2)=657;
  v2(151,3)=T229+T17*params(4)*T17+T17*params(4)*T17;
  v2(152,1)=7;
  v2(152,2)=360;
  v2(152,3)=  v2(151,3);
  v2(153,1)=8;
  v2(153,2)=176;
  v2(153,3)=T319;
  v2(154,1)=8;
  v2(154,2)=380;
  v2(154,3)=T150;
  v2(155,1)=8;
  v2(155,2)=182;
  v2(155,3)=  v2(154,3);
  v2(156,1)=8;
  v2(156,2)=386;
  v2(156,3)=y(25)*(-(params(6)*exp(y(12)+y(6)*(params(6)-1))))+y(19)*(-exp(y(12)+params(6)*y(6)));
  v2(157,1)=8;
  v2(157,2)=618;
  v2(157,3)=(-(params(6)*exp(y(12)+params(6)*y(6))));
  v2(158,1)=8;
  v2(158,2)=189;
  v2(158,3)=  v2(157,3);
  v2(159,1)=8;
  v2(159,2)=624;
  v2(159,3)=(-exp(y(12)+params(6)*y(6)));
  v2(160,1)=8;
  v2(160,2)=393;
  v2(160,3)=  v2(159,3);
  v2(161,1)=8;
  v2(161,2)=822;
  v2(161,3)=T144;
  v2(162,1)=8;
  v2(162,2)=195;
  v2(162,3)=  v2(161,3);
  v2(163,1)=8;
  v2(163,2)=828;
  v2(163,3)=(-(params(6)*exp(y(12)+y(6)*(params(6)-1))));
  v2(164,1)=8;
  v2(164,2)=399;
  v2(164,3)=  v2(163,3);
  v2(165,1)=9;
  v2(165,2)=141;
  v2(165,3)=T118;
  v2(166,1)=9;
  v2(166,2)=277;
  v2(166,3)=T209;
  v2(167,1)=9;
  v2(167,2)=145;
  v2(167,3)=  v2(166,3);
  v2(168,1)=9;
  v2(168,2)=281;
  v2(168,3)=T118+y(27)*(-exp(y(13)-y(9)));
  v2(169,1)=9;
  v2(169,2)=413;
  v2(169,3)=T118;
  v2(170,1)=9;
  v2(170,2)=149;
  v2(170,3)=  v2(169,3);
  v2(171,1)=9;
  v2(171,2)=417;
  v2(171,3)=exp(y(13)-y(9))*y(27)+T209;
  v2(172,1)=9;
  v2(172,2)=285;
  v2(172,3)=  v2(171,3);
  v2(173,1)=9;
  v2(173,2)=421;
  v2(173,3)=y(27)*(-exp(y(13)-y(9)))+T118+exp(y(13))*y(25);
  v2(174,1)=9;
  v2(174,2)=685;
  v2(174,3)=T64;
  v2(175,1)=9;
  v2(175,2)=157;
  v2(175,3)=  v2(174,3);
  v2(176,1)=9;
  v2(176,2)=689;
  v2(176,3)=(-T64);
  v2(177,1)=9;
  v2(177,2)=293;
  v2(177,3)=  v2(176,3);
  v2(178,1)=9;
  v2(178,2)=693;
  v2(178,3)=T64;
  v2(179,1)=9;
  v2(179,2)=429;
  v2(179,3)=  v2(178,3);
  v2(180,1)=9;
  v2(180,2)=829;
  v2(180,3)=exp(y(13));
  v2(181,1)=9;
  v2(181,2)=433;
  v2(181,3)=  v2(180,3);
  v2(182,1)=9;
  v2(182,2)=893;
  v2(182,3)=exp(y(13)-y(9));
  v2(183,1)=9;
  v2(183,2)=299;
  v2(183,3)=  v2(182,3);
  v2(184,1)=9;
  v2(184,2)=897;
  v2(184,3)=(-exp(y(13)-y(9)));
  v2(185,1)=9;
  v2(185,2)=435;
  v2(185,3)=  v2(184,3);
  v2(186,1)=10;
  v2(186,2)=281;
  v2(186,3)=exp(y(9)-y(14))*y(28);
  v2(187,1)=10;
  v2(187,2)=316;
  v2(187,3)=exp(y(14)-y(10))*y(22);
  v2(188,1)=10;
  v2(188,2)=451;
  v2(188,3)=y(28)*(-exp(y(9)-y(14)));
  v2(189,1)=10;
  v2(189,2)=286;
  v2(189,3)=  v2(188,3);
  v2(190,1)=10;
  v2(190,2)=452;
  v2(190,3)=y(22)*(-exp(y(14)-y(10)));
  v2(191,1)=10;
  v2(191,2)=320;
  v2(191,3)=  v2(190,3);
  v2(192,1)=10;
  v2(192,2)=456;
  v2(192,3)=exp(y(9)-y(14))*y(28)+exp(y(14))*y(26)+exp(y(14)-y(10))*y(22);
  v2(193,1)=10;
  v2(193,2)=724;
  v2(193,3)=(-exp(y(14)-y(10)));
  v2(194,1)=10;
  v2(194,2)=328;
  v2(194,3)=  v2(193,3);
  v2(195,1)=10;
  v2(195,2)=728;
  v2(195,3)=exp(y(14)-y(10));
  v2(196,1)=10;
  v2(196,2)=464;
  v2(196,3)=  v2(195,3);
  v2(197,1)=10;
  v2(197,2)=864;
  v2(197,3)=exp(y(14));
  v2(198,1)=10;
  v2(198,2)=468;
  v2(198,3)=  v2(197,3);
  v2(199,1)=10;
  v2(199,2)=927;
  v2(199,3)=exp(y(9)-y(14));
  v2(200,1)=10;
  v2(200,2)=300;
  v2(200,3)=  v2(199,3);
  v2(201,1)=10;
  v2(201,2)=932;
  v2(201,3)=(-exp(y(9)-y(14)));
  v2(202,1)=10;
  v2(202,2)=470;
  v2(202,3)=  v2(201,3);
  v2(203,1)=11;
  v2(203,2)=491;
  v2(203,3)=exp(y(15))*y(27);
  v2(204,1)=11;
  v2(204,2)=899;
  v2(204,3)=exp(y(15));
  v2(205,1)=11;
  v2(205,2)=503;
  v2(205,3)=  v2(204,3);
  v2(206,1)=12;
  v2(206,2)=526;
  v2(206,3)=exp(y(16))*y(28);
  v2(207,1)=12;
  v2(207,2)=934;
  v2(207,3)=exp(y(16));
  v2(208,1)=12;
  v2(208,2)=538;
  v2(208,3)=  v2(207,3);
  v2(209,1)=13;
  v2(209,2)=561;
  v2(209,3)=exp(y(17))*y(29);
  v2(210,1)=13;
  v2(210,2)=969;
  v2(210,3)=exp(y(17));
  v2(211,1)=13;
  v2(211,2)=573;
  v2(211,3)=  v2(210,3);
  v2(212,1)=14;
  v2(212,2)=211;
  v2(212,3)=(-exp(y(7)));
  v2(213,1)=14;
  v2(213,2)=246;
  v2(213,3)=exp(y(8));
  v2(214,1)=14;
  v2(214,2)=351;
  v2(214,3)=(-(T15*(T17*2*(T17-1)+T17*2*T17)));
  v2(215,1)=15;
  v2(215,2)=176;
  v2(215,3)=(-(params(6)*params(6)*exp(y(12)+params(6)*y(6))));
  v2(216,1)=15;
  v2(216,2)=246;
  v2(216,3)=exp(y(8));
  v2(217,1)=15;
  v2(217,2)=380;
  v2(217,3)=(-(params(6)*exp(y(12)+params(6)*y(6))));
  v2(218,1)=15;
  v2(218,2)=182;
  v2(218,3)=  v2(217,3);
  v2(219,1)=15;
  v2(219,2)=386;
  v2(219,3)=(-exp(y(12)+params(6)*y(6)));
  v2(220,1)=16;
  v2(220,2)=141;
  v2(220,3)=T122;
  v2(221,1)=16;
  v2(221,2)=211;
  v2(221,3)=T361;
  v2(222,1)=16;
  v2(222,2)=993;
  v2(222,3)=(-(exp(y(31))*(exp(y(31))-1)*params(4)*params(1)*(-params(2))*params(2)*exp((-params(2))*(y(30)-y(7)))));
  v2(223,1)=16;
  v2(223,2)=234;
  v2(223,3)=  v2(222,3);
  v2(224,1)=16;
  v2(224,2)=1016;
  v2(224,3)=(-(exp(y(31))*(exp(y(31))-1)*params(4)*params(1)*(-params(2))*(-params(2))*exp((-params(2))*(y(30)-y(7)))));
  v2(225,1)=16;
  v2(225,2)=243;
  v2(225,3)=T122;
  v2(226,1)=16;
  v2(226,2)=144;
  v2(226,3)=  v2(225,3);
  v2(227,1)=16;
  v2(227,2)=246;
  v2(227,3)=(-T43);
  v2(228,1)=16;
  v2(228,2)=351;
  v2(228,3)=T229+T17*params(4)*T17+T17*params(4)*T17;
  v2(229,1)=16;
  v2(229,2)=1027;
  v2(229,3)=(-T419);
  v2(230,1)=16;
  v2(230,2)=235;
  v2(230,3)=  v2(229,3);
  v2(231,1)=16;
  v2(231,2)=1050;
  v2(231,3)=(-(exp(y(31))*(exp(y(31))-1)*params(4)*params(1)*(-params(2))*exp((-params(2))*(y(30)-y(7)))+exp(y(31))*exp(y(31))*params(4)*params(1)*(-params(2))*exp((-params(2))*(y(30)-y(7)))));
  v2(232,1)=16;
  v2(232,2)=1017;
  v2(232,3)=  v2(231,3);
  v2(233,1)=16;
  v2(233,2)=1051;
  v2(233,3)=(-(T424+exp(y(31))*params(4)*params(1)*exp((-params(2))*(y(30)-y(7)))*exp(y(31))+exp(y(31))*params(4)*params(1)*exp((-params(2))*(y(30)-y(7)))*exp(y(31))));
  v2(234,1)=17;
  v2(234,2)=141;
  v2(234,3)=T64;
  v2(235,1)=17;
  v2(235,2)=277;
  v2(235,3)=(-T64);
  v2(236,1)=17;
  v2(236,2)=145;
  v2(236,3)=  v2(235,3);
  v2(237,1)=17;
  v2(237,2)=281;
  v2(237,3)=T64;
  v2(238,1)=17;
  v2(238,2)=413;
  v2(238,3)=T64;
  v2(239,1)=17;
  v2(239,2)=149;
  v2(239,3)=  v2(238,3);
  v2(240,1)=17;
  v2(240,2)=417;
  v2(240,3)=(-T64);
  v2(241,1)=17;
  v2(241,2)=285;
  v2(241,3)=  v2(240,3);
  v2(242,1)=17;
  v2(242,2)=421;
  v2(242,3)=T64;
  v2(243,1)=18;
  v2(243,2)=316;
  v2(243,3)=exp(y(14)-y(10));
  v2(244,1)=18;
  v2(244,2)=452;
  v2(244,3)=(-exp(y(14)-y(10)));
  v2(245,1)=18;
  v2(245,2)=320;
  v2(245,3)=  v2(244,3);
  v2(246,1)=18;
  v2(246,2)=456;
  v2(246,3)=exp(y(14)-y(10));
  v2(247,1)=19;
  v2(247,2)=36;
  v2(247,3)=(-(params(7)*exp(y(2))));
  v2(248,1)=19;
  v2(248,2)=281;
  v2(248,3)=exp(y(9));
  v2(249,1)=19;
  v2(249,2)=316;
  v2(249,3)=(-((1-params(7))*exp(y(10))));
  v2(250,1)=21;
  v2(250,2)=176;
  v2(250,3)=(-(params(6)*(params(6)-1)*(params(6)-1)*exp(y(12)+y(6)*(params(6)-1))));
  v2(251,1)=21;
  v2(251,2)=380;
  v2(251,3)=T144;
  v2(252,1)=21;
  v2(252,2)=182;
  v2(252,3)=  v2(251,3);
  v2(253,1)=21;
  v2(253,2)=386;
  v2(253,3)=(-(params(6)*exp(y(12)+y(6)*(params(6)-1))));
  v2(254,1)=21;
  v2(254,2)=421;
  v2(254,3)=exp(y(13));
  v2(255,1)=22;
  v2(255,2)=176;
  v2(255,3)=(-(params(8)*params(3)*params(3)*exp(y(6)*params(3)+y(7)*params(2))));
  v2(256,1)=22;
  v2(256,2)=210;
  v2(256,3)=(-(params(8)*params(2)*params(3)*exp(y(6)*params(3)+y(7)*params(2))));
  v2(257,1)=22;
  v2(257,2)=177;
  v2(257,3)=  v2(256,3);
  v2(258,1)=22;
  v2(258,2)=211;
  v2(258,3)=(-(params(8)*params(2)*params(2)*exp(y(6)*params(3)+y(7)*params(2))));
  v2(259,1)=22;
  v2(259,2)=456;
  v2(259,3)=exp(y(14));
  v2(260,1)=23;
  v2(260,2)=281;
  v2(260,3)=(-exp(y(13)-y(9)));
  v2(261,1)=23;
  v2(261,2)=417;
  v2(261,3)=exp(y(13)-y(9));
  v2(262,1)=23;
  v2(262,2)=285;
  v2(262,3)=  v2(261,3);
  v2(263,1)=23;
  v2(263,2)=421;
  v2(263,3)=(-exp(y(13)-y(9)));
  v2(264,1)=23;
  v2(264,2)=491;
  v2(264,3)=exp(y(15));
  v2(265,1)=24;
  v2(265,2)=281;
  v2(265,3)=(-exp(y(9)-y(14)));
  v2(266,1)=24;
  v2(266,2)=451;
  v2(266,3)=exp(y(9)-y(14));
  v2(267,1)=24;
  v2(267,2)=286;
  v2(267,3)=  v2(266,3);
  v2(268,1)=24;
  v2(268,2)=456;
  v2(268,3)=(-exp(y(9)-y(14)));
  v2(269,1)=24;
  v2(269,2)=526;
  v2(269,3)=exp(y(16));
  v2(270,1)=25;
  v2(270,2)=176;
  v2(270,3)=(-exp(y(6)));
  v2(271,1)=25;
  v2(271,2)=561;
  v2(271,3)=exp(y(17));
  g2 = sparse(v2(:,1),v2(:,2),v2(:,3),25,1156);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],25,39304);
end
end
