function [residual, g1, g2] = bmcomp2_objective_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                    columns: equations in order of declaration
%                                                    rows: variables in declaration order
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: equations in order of declaration
%                                                       rows: variables in declaration order
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 1, 1);

%
% Model equations
%

residual(1) = exp((1-params(2))*y(3))/(1-params(2))-params(8)*exp((1+params(3))*y(2))/(1+params(3));
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(1, 25);

  %
  % Jacobian matrix
  %

  g1(1,2)=(-(params(8)*(1+params(3))*exp((1+params(3))*y(2))/(1+params(3))));
  g1(1,3)=(1-params(2))*exp((1-params(2))*y(3))/(1-params(2));
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  v2 = zeros(2,3);
  v2(1,1)=1;
  v2(1,2)=27;
  v2(1,3)=(-(params(8)*(1+params(3))*(1+params(3))*exp((1+params(3))*y(2))/(1+params(3))));
  v2(2,1)=1;
  v2(2,2)=53;
  v2(2,3)=(1-params(2))*(1-params(2))*exp((1-params(2))*y(3))/(1-params(2));
  g2 = sparse(v2(:,1),v2(:,2),v2(:,3),1,625);
end
end
