function [residual, g1, g2] = bmcomp2_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                    columns: equations in order of declaration
%                                                    rows: variables in declaration order
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: equations in order of declaration
%                                                       rows: variables in declaration order
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 25, 1);

%
% Model equations
%

T28 = (-(exp(y(4))*(1-params(5))*(-(params(5)/(params(5)-1)*exp(y(1))))));
T29 = y(16)*T28;
T30 = exp(y(1)+y(9)-y(5))*y(17)+T29;
T75 = y(21)*(-(params(6)*(params(6)-1)*exp(y(8)+y(2)*(params(6)-1))))+y(15)*(-(params(6)*exp(y(8)+y(2)*params(6))));
T107 = params(12)^(-1);
T122 = exp(y(4))*(1-params(5))*(1+params(11)-params(5)/(params(5)-1)*exp(y(1)));
T172 = exp(y(7))*(exp(y(7))-1)*params(4)+exp(y(7))*exp(y(7))*params(4);
T178 = (-(params(4)/2*exp(y(7))*2*(exp(y(7))-1)));
T186 = exp(y(7))*(exp(y(7))-1)*params(4)*params(1)+exp(y(7))*exp(y(7))*params(4)*params(1);
residual(1) = T30;
residual(2) = (-(params(8)*(1+params(3))*exp((1+params(3))*y(2))/(1+params(3))))+y(25)*(-exp(y(2)))+y(22)*(-(params(8)*params(3)*exp(params(3)*y(2)+y(3)*params(2))))+T75;
residual(3) = (1-params(2))*exp(y(3)*(1-params(2)))/(1-params(2))+y(22)*(-(params(8)*params(2)*exp(params(3)*y(2)+y(3)*params(2))))+y(16)*(-(exp(y(7))*(exp(y(7))-1)*params(4)*params(2)*params(1)))+y(14)*(-exp(y(3)))+T107*y(16)*(-(exp(y(7))*(exp(y(7))-1)*params(4)*params(1)*(-params(2))));
residual(4) = y(16)*(-T122)+exp(y(4))*y(15)+exp(y(4))*y(14);
residual(5) = y(24)*(-exp(y(5)-y(10)))+exp(y(9)-y(5))*y(23)+exp(y(5))*y(19)+y(17)*(-exp(y(1)+y(9)-y(5)))+params(12)*y(19)*(-(exp(y(5))*params(7)));
residual(6) = y(19)*(-((1-params(7))*exp(y(6))))+y(18)*(-exp(y(10)-y(6)));
residual(7) = y(16)*T172+y(14)*T178+T107*y(16)*(-T186);
residual(8) = y(21)*(-(params(6)*exp(y(8)+y(2)*(params(6)-1))))+y(20)+y(15)*(-exp(y(8)+y(2)*params(6)))+params(12)*y(20)*(-params(9));
residual(9) = y(23)*(-exp(y(9)-y(5)))+exp(y(1)+y(9)-y(5))*y(17)+y(21)*exp(y(9));
residual(10) = y(24)*exp(y(5)-y(10))+y(22)*exp(y(10))+y(18)*exp(y(10)-y(6));
residual(11) = y(23)*exp(y(11));
residual(12) = y(24)*exp(y(12));
residual(13) = y(25)*exp(y(13));
residual(14) = exp(y(4))-(exp(y(3))+params(10)+params(4)/2*(exp(y(7))-1)^2);
residual(15) = exp(y(4))-exp(y(8)+y(2)*params(6));
residual(16) = exp(y(7))*(exp(y(7))-1)*params(4)-(T122+exp(y(7))*(exp(y(7))-1)*params(4)*params(1));
residual(17) = exp(y(1)+y(9)-y(5))-1;
residual(18) = exp(y(10)-y(6))-1;
residual(19) = exp(y(5))-(exp(y(5))*params(7)+(1-params(7))*exp(y(6)));
residual(20) = y(8)-(y(8)*params(9)+x(1));
residual(21) = exp(y(9))-params(6)*exp(y(8)+y(2)*(params(6)-1));
residual(22) = exp(y(10))-params(8)*exp(params(3)*y(2)+y(3)*params(2));
residual(23) = exp(y(11))-exp(y(9)-y(5));
residual(24) = exp(y(12))-exp(y(5)-y(10));
residual(25) = exp(y(13))-exp(y(2));
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(25, 25);

  %
  % Jacobian matrix
  %

  g1(1,1)=T30;
  g1(1,4)=T29;
  g1(1,5)=y(17)*(-exp(y(1)+y(9)-y(5)));
  g1(1,9)=exp(y(1)+y(9)-y(5))*y(17);
  g1(1,16)=T28;
  g1(1,17)=exp(y(1)+y(9)-y(5));
  g1(2,2)=(-(params(8)*(1+params(3))*(1+params(3))*exp((1+params(3))*y(2))/(1+params(3))))+y(25)*(-exp(y(2)))+y(22)*(-(params(8)*params(3)*params(3)*exp(params(3)*y(2)+y(3)*params(2))))+y(21)*(-(params(6)*(params(6)-1)*(params(6)-1)*exp(y(8)+y(2)*(params(6)-1))))+y(15)*(-(params(6)*params(6)*exp(y(8)+y(2)*params(6))));
  g1(2,3)=y(22)*(-(params(8)*params(3)*params(2)*exp(params(3)*y(2)+y(3)*params(2))));
  g1(2,8)=T75;
  g1(2,15)=(-(params(6)*exp(y(8)+y(2)*params(6))));
  g1(2,21)=(-(params(6)*(params(6)-1)*exp(y(8)+y(2)*(params(6)-1))));
  g1(2,22)=(-(params(8)*params(3)*exp(params(3)*y(2)+y(3)*params(2))));
  g1(2,25)=(-exp(y(2)));
  g1(3,2)=y(22)*(-(params(8)*params(2)*params(3)*exp(params(3)*y(2)+y(3)*params(2))));
  g1(3,3)=(1-params(2))*(1-params(2))*exp(y(3)*(1-params(2)))/(1-params(2))+y(14)*(-exp(y(3)))+y(22)*(-(params(8)*params(2)*params(2)*exp(params(3)*y(2)+y(3)*params(2))));
  g1(3,7)=y(16)*(-(exp(y(7))*(exp(y(7))-1)*params(4)*params(2)*params(1)+exp(y(7))*exp(y(7))*params(4)*params(2)*params(1)))+T107*y(16)*(-(exp(y(7))*(exp(y(7))-1)*params(4)*params(1)*(-params(2))+exp(y(7))*exp(y(7))*params(4)*params(1)*(-params(2))));
  g1(3,14)=(-exp(y(3)));
  g1(3,16)=(-(exp(y(7))*(exp(y(7))-1)*params(4)*params(2)*params(1)))+T107*(-(exp(y(7))*(exp(y(7))-1)*params(4)*params(1)*(-params(2))));
  g1(3,22)=(-(params(8)*params(2)*exp(params(3)*y(2)+y(3)*params(2))));
  g1(4,1)=T29;
  g1(4,4)=y(16)*(-T122)+exp(y(4))*y(15)+exp(y(4))*y(14);
  g1(4,14)=exp(y(4));
  g1(4,15)=exp(y(4));
  g1(4,16)=(-T122);
  g1(5,1)=y(17)*(-exp(y(1)+y(9)-y(5)));
  g1(5,5)=y(24)*(-exp(y(5)-y(10)))+y(23)*(-exp(y(9)-y(5)))+exp(y(5))*y(19)+exp(y(1)+y(9)-y(5))*y(17)+params(12)*y(19)*(-(exp(y(5))*params(7)));
  g1(5,9)=exp(y(9)-y(5))*y(23)+y(17)*(-exp(y(1)+y(9)-y(5)));
  g1(5,10)=y(24)*exp(y(5)-y(10));
  g1(5,17)=(-exp(y(1)+y(9)-y(5)));
  g1(5,19)=exp(y(5))+params(12)*(-(exp(y(5))*params(7)));
  g1(5,23)=exp(y(9)-y(5));
  g1(5,24)=(-exp(y(5)-y(10)));
  g1(6,6)=y(19)*(-((1-params(7))*exp(y(6))))+y(18)*exp(y(10)-y(6));
  g1(6,10)=y(18)*(-exp(y(10)-y(6)));
  g1(6,18)=(-exp(y(10)-y(6)));
  g1(6,19)=(-((1-params(7))*exp(y(6))));
  g1(7,7)=y(16)*(T172+exp(y(7))*exp(y(7))*params(4)+exp(y(7))*exp(y(7))*params(4))+y(14)*(-(params(4)/2*(exp(y(7))*2*(exp(y(7))-1)+exp(y(7))*2*exp(y(7)))))+T107*y(16)*(-(T186+exp(y(7))*exp(y(7))*params(4)*params(1)+exp(y(7))*exp(y(7))*params(4)*params(1)));
  g1(7,14)=T178;
  g1(7,16)=T172+T107*(-T186);
  g1(8,2)=T75;
  g1(8,8)=y(21)*(-(params(6)*exp(y(8)+y(2)*(params(6)-1))))+y(15)*(-exp(y(8)+y(2)*params(6)));
  g1(8,15)=(-exp(y(8)+y(2)*params(6)));
  g1(8,20)=1+params(12)*(-params(9));
  g1(8,21)=(-(params(6)*exp(y(8)+y(2)*(params(6)-1))));
  g1(9,1)=exp(y(1)+y(9)-y(5))*y(17);
  g1(9,5)=exp(y(9)-y(5))*y(23)+y(17)*(-exp(y(1)+y(9)-y(5)));
  g1(9,9)=y(23)*(-exp(y(9)-y(5)))+exp(y(1)+y(9)-y(5))*y(17)+y(21)*exp(y(9));
  g1(9,17)=exp(y(1)+y(9)-y(5));
  g1(9,21)=exp(y(9));
  g1(9,23)=(-exp(y(9)-y(5)));
  g1(10,5)=y(24)*exp(y(5)-y(10));
  g1(10,6)=y(18)*(-exp(y(10)-y(6)));
  g1(10,10)=y(24)*(-exp(y(5)-y(10)))+y(22)*exp(y(10))+y(18)*exp(y(10)-y(6));
  g1(10,18)=exp(y(10)-y(6));
  g1(10,22)=exp(y(10));
  g1(10,24)=exp(y(5)-y(10));
  g1(11,11)=y(23)*exp(y(11));
  g1(11,23)=exp(y(11));
  g1(12,12)=y(24)*exp(y(12));
  g1(12,24)=exp(y(12));
  g1(13,13)=y(25)*exp(y(13));
  g1(13,25)=exp(y(13));
  g1(14,3)=(-exp(y(3)));
  g1(14,4)=exp(y(4));
  g1(14,7)=T178;
  g1(15,2)=(-(params(6)*exp(y(8)+y(2)*params(6))));
  g1(15,4)=exp(y(4));
  g1(15,8)=(-exp(y(8)+y(2)*params(6)));
  g1(16,1)=T28;
  g1(16,4)=(-T122);
  g1(16,7)=T172-T186;
  g1(17,1)=exp(y(1)+y(9)-y(5));
  g1(17,5)=(-exp(y(1)+y(9)-y(5)));
  g1(17,9)=exp(y(1)+y(9)-y(5));
  g1(18,6)=(-exp(y(10)-y(6)));
  g1(18,10)=exp(y(10)-y(6));
  g1(19,5)=exp(y(5))-exp(y(5))*params(7);
  g1(19,6)=(-((1-params(7))*exp(y(6))));
  g1(20,8)=1-params(9);
  g1(21,2)=(-(params(6)*(params(6)-1)*exp(y(8)+y(2)*(params(6)-1))));
  g1(21,8)=(-(params(6)*exp(y(8)+y(2)*(params(6)-1))));
  g1(21,9)=exp(y(9));
  g1(22,2)=(-(params(8)*params(3)*exp(params(3)*y(2)+y(3)*params(2))));
  g1(22,3)=(-(params(8)*params(2)*exp(params(3)*y(2)+y(3)*params(2))));
  g1(22,10)=exp(y(10));
  g1(23,5)=exp(y(9)-y(5));
  g1(23,9)=(-exp(y(9)-y(5)));
  g1(23,11)=exp(y(11));
  g1(24,5)=(-exp(y(5)-y(10)));
  g1(24,10)=exp(y(5)-y(10));
  g1(24,12)=exp(y(12));
  g1(25,2)=(-exp(y(2)));
  g1(25,13)=exp(y(13));
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],25,625);
end
end
