function [residual, g1, g2] = bmeb2_objective_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                    columns: equations in order of declaration
%                                                    rows: variables in declaration order
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: equations in order of declaration
%                                                       rows: variables in declaration order
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 1, 1);

%
% Model equations
%

T27 = (-(exp(y(4))*params(14)*exp((1+params(3))*y(6))/(1+params(3))));
T31 = (-(exp(y(4))*params(14)*(1+params(3))*exp((1+params(3))*y(6))/(1+params(3))));
residual(1) = exp((1-params(2))*y(7))/(1-params(2))-exp(y(4))*params(14)*exp((1+params(3))*y(6))/(1+params(3));
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(1, 41);

  %
  % Jacobian matrix
  %

  g1(1,4)=T27;
  g1(1,6)=T31;
  g1(1,7)=(1-params(2))*exp((1-params(2))*y(7))/(1-params(2));
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  v2 = zeros(5,3);
  v2(1,1)=1;
  v2(1,2)=127;
  v2(1,3)=T27;
  v2(2,1)=1;
  v2(2,2)=209;
  v2(2,3)=T31;
  v2(3,1)=1;
  v2(3,2)=129;
  v2(3,3)=  v2(2,3);
  v2(4,1)=1;
  v2(4,2)=211;
  v2(4,3)=(-(exp(y(4))*params(14)*(1+params(3))*(1+params(3))*exp((1+params(3))*y(6))/(1+params(3))));
  v2(5,1)=1;
  v2(5,2)=253;
  v2(5,3)=(1-params(2))*(1-params(2))*exp((1-params(2))*y(7))/(1-params(2));
  g2 = sparse(v2(:,1),v2(:,2),v2(:,3),1,1681);
end
end
