function [residual, g1, g2] = bmrtmlin_objective_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                    columns: equations in order of declaration
%                                                    rows: variables in declaration order
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: equations in order of declaration
%                                                       rows: variables in declaration order
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 1, 1);

%
% Model equations
%

T21 = 1/params(21);
T33 = params(9)/params(21)/(1+params(3));
T47 = params(6)*params(23)/params(21)/(1-params(5));
residual(1) = (-params(7))/params(27)*y(14)^2-params(2)*y(7)^2+T21*(y(8)^2-y(4)^2)+T33*(y(4)^2-(y(4)+(1+params(3))*y(6))^2)-T47*(params(5)*y(3)^2+(1-params(5))*y(2)^2-y(11)^2);
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(1, 45);

  %
  % Jacobian matrix
  %

  g1(1,2)=(-(T47*(1-params(5))*2*y(2)));
  g1(1,3)=(-(T47*params(5)*2*y(3)));
  g1(1,4)=T21*(-(2*y(4)))+T33*(2*y(4)-2*(y(4)+(1+params(3))*y(6)));
  g1(1,6)=T33*(-((1+params(3))*2*(y(4)+(1+params(3))*y(6))));
  g1(1,7)=(-(params(2)*2*y(7)));
  g1(1,8)=T21*2*y(8);
  g1(1,11)=(-(T47*(-(2*y(11)))));
  g1(1,14)=(-params(7))/params(27)*2*y(14);
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  v2 = zeros(10,3);
  v2(1,1)=1;
  v2(1,2)=47;
  v2(1,3)=(-(T47*2*(1-params(5))));
  v2(2,1)=1;
  v2(2,2)=93;
  v2(2,3)=(-(T47*2*params(5)));
  v2(3,1)=1;
  v2(3,2)=139;
  v2(3,3)=T21*(-2);
  v2(4,1)=1;
  v2(4,2)=229;
  v2(4,3)=T33*(-(2*(1+params(3))));
  v2(5,1)=1;
  v2(5,2)=141;
  v2(5,3)=  v2(4,3);
  v2(6,1)=1;
  v2(6,2)=231;
  v2(6,3)=T33*(-((1+params(3))*2*(1+params(3))));
  v2(7,1)=1;
  v2(7,2)=277;
  v2(7,3)=(-(2*params(2)));
  v2(8,1)=1;
  v2(8,2)=323;
  v2(8,3)=2*T21;
  v2(9,1)=1;
  v2(9,2)=461;
  v2(9,3)=(-(T47*(-2)));
  v2(10,1)=1;
  v2(10,2)=599;
  v2(10,3)=2*(-params(7))/params(27);
  g2 = sparse(v2(:,1),v2(:,2),v2(:,3),1,2025);
end
end
